pub fn allocation_stats() -> AllocationsExpand description
Return a snapshot of coarse process-wide allocation counters.
These counters are updated only when the global allocator wrapper was
configured with PprofAlloc::with_stats.
pub fn allocation_stats() -> AllocationsReturn a snapshot of coarse process-wide allocation counters.
These counters are updated only when the global allocator wrapper was
configured with PprofAlloc::with_stats.