snapshot

Function snapshot 

pub fn snapshot() -> MemorySnapshot
Capture a best-effort process memory snapshot.

Individual probes that fail are represented as None in the returned MemorySnapshot. This function intentionally does not fail as a whole.