pub struct MemorySnapshot {
pub captured_at_unix_ms: u64,
pub capture_mode: CaptureMode,
pub allocation_stats: Allocations,
pub pprof: PprofSummary,
pub allocator: AllocatorSnapshot,
pub cgroup: Option<MemoryStat>,
pub smaps: Option<ProcessStats>,
}Expand description
Best-effort snapshot of allocation and memory state for the current process created by snapshot().
Snapshot collection never fails as a whole. Optional fields are None when
the corresponding operating-system or allocator probe is unavailable.
Fields
captured_at_unix_ms: u64Wall-clock capture time as milliseconds since the Unix epoch.
capture_mode: CaptureModeStack capture implementation compiled into this build.
allocation_stats: AllocationsCoarse process-wide counters from allocation_stats.
pprof: PprofSummarySummary of recorded pprof stack-attributed allocation data.
allocator: AllocatorSnapshotActive allocator identity and allocator-specific memory stats, if available.
cgroup: Option<MemoryStat>cgroup v2 memory stats for this process, when available.
smaps: Option<ProcessStats>/proc/self/smaps_rollup memory stats for this process, when available.