pub struct PprofSummary {
pub total_stacks: u64,
pub live_stacks: u64,
pub alloc_space_bytes: u64,
pub inuse_space_bytes: u64,
pub alloc_objects: u64,
pub inuse_objects: u64,
}Expand description
Summary of the currently recorded pprof allocation profile.
Values are scaled according to the active pprof sample rate, so they are estimates when sampling is enabled.
Fields
total_stacks: u64Number of distinct stack traces recorded in the profile.
live_stacks: u64Number of distinct stack traces with estimated live bytes greater than zero.
alloc_space_bytes: u64Estimated cumulative allocated bytes across all recorded stacks.
inuse_space_bytes: u64Estimated currently live bytes across all recorded stacks.
alloc_objects: u64Estimated cumulative allocation count across all recorded stacks.
inuse_objects: u64Estimated currently live allocation count across all recorded stacks.