pub fn snapshot() -> MemorySnapshotExpand description
Capture a best-effort process memory snapshot.
Individual probes that fail are represented as None in the returned
MemorySnapshot. This function intentionally does not fail as a whole.
pub fn snapshot() -> MemorySnapshotCapture a best-effort process memory snapshot.
Individual probes that fail are represented as None in the returned
MemorySnapshot. This function intentionally does not fail as a whole.